summaryrefslogtreecommitdiffstats
path: root/core/uemis-downloader.c
diff options
context:
space:
mode:
authorGravatar Dirk Hohndel <dirk@hohndel.org>2019-03-17 13:58:11 -0700
committerGravatar Dirk Hohndel <dirk@hohndel.org>2019-03-17 15:11:31 -0700
commit69248141c53bdee3ccac5231a3236dee5b920d56 (patch)
tree2cccc34c89e020aa79135d0463c5abc0497e3ae6 /core/uemis-downloader.c
parentb457965f50e7e0777a5b55e19d6fb0e848ee985d (diff)
downloadsubsurface-69248141c53bdee3ccac5231a3236dee5b920d56.tar.gz
Core: remove variable name conflict
Having a parameter with the same name as a global variable is potentially confusing. Found via LGTM.com Signed-off-by: Dirk Hohndel <dirk@hohndel.org>
Diffstat (limited to 'core/uemis-downloader.c')
-rw-r--r--core/uemis-downloader.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/core/uemis-downloader.c b/core/uemis-downloader.c
index f66713565..930abbc18 100644
--- a/core/uemis-downloader.c
+++ b/core/uemis-downloader.c
@@ -505,16 +505,16 @@ static void uemis_increased_timeout(int *timeout)
usleep(*timeout);
}
-static char *build_ans_path(const char *path, int filenr)
+static char *build_ans_path(const char *path, int filenumber)
{
char *intermediate, *ans_path, fl[13];
/* Clamp filenr into the 0..9999 range. This is never necessary,
* as filenr can never go above UEMIS_MAX_FILES, but gcc doesn't
* recognize that and produces very noisy warnings. */
- filenr = filenr < 0 ? 0 : filenr % 10000;
+ filenumber = filenumber < 0 ? 0 : filenumber % 10000;
- snprintf(fl, 13, "ANS%d.TXT", filenr);
+ snprintf(fl, 13, "ANS%d.TXT", filenumber);
intermediate = build_filename(path, "ANS");
ans_path = build_filename(intermediate, fl);
free(intermediate);
@@ -505,16 +505,16 @@ static void uemis_increased_timeout(int *timeout)
{
char *intermediate, *ans_path, fl[13];
- /* Clamp filenr into the 0..9999 range. This is never necessary,
- * as filenr can never go above UEMIS_MAX_FILES, but gcc doesn't
+ /* Clamp filenumber into the 0..9999 range. This is never necessary,
+ * as filenumber can never go above UEMIS_MAX_FILES, but gcc doesn't
* recognize that and produces very noisy warnings. */